Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJean Michel-Lemieux2003-07-31 15:01:18 +0000
committerJean Michel-Lemieux2003-07-31 15:01:18 +0000
commitf8eafc37da18446d6d093b44d7879a93104c1fc4 (patch)
treea88228abd8277fc8649c684f46caa0d5a444472b /bundles
parentb8abbecfd5c40de550d2e69dc990c1442c876e62 (diff)
downloadeclipse.platform.team-f8eafc37da18446d6d093b44d7879a93104c1fc4.tar.gz
eclipse.platform.team-f8eafc37da18446d6d093b44d7879a93104c1fc4.tar.xz
eclipse.platform.team-f8eafc37da18446d6d093b44d7879a93104c1fc4.zip
Bug 40756 : Selecting in Annotate Editor no longer tracks revision properly
Bug 40565 : Annotate view shoud not have border
Diffstat (limited to 'bundles')
-rw-r--r--bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/AnnotateView.java15
-rw-r--r--bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/messages.properties2
2 files changed, 13 insertions, 4 deletions
diff --git a/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/messages.properties b/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/messages.properties
index d888a6312..a40e94e41 100644
--- a/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/messages.properties
+++ b/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/messages.properties
@@ -76,7 +76,7 @@ CVSAction.multipleProblemsMessage=Multiple problems occurred:
CVSAction.mixingTagsTitle=Confirm Mixing Tags
CVSAction.mixingTags=You are mixing tags within a project. Beware that synchronization uses the tag information associated with each resource to determine the remote resource with which the local resource is compared. \n\nThis means that the part(s) of your project that you are replacing with another tag will be synchronized with the tag ''{0}'' while other resources in the project will be synchronized with another tag. \n\nDo you wish to continue?
-CVSAnnotateView.showFileAnnotation=CVS Annotate {0}
+CVSAnnotateView.showFileAnnotation=CVS Annotate - {0}
CVSAnnotateView.viewInstructions=This view shows annotations for a file in CVS. Select a file and then choose \"Team->Show Annotation\" from the context menu.
CVSCatchupReleaseViewer.commit=&Commit...

Back to the top
diff --git a/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/AnnotateView.java b/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/AnnotateView.java
index 0a4280732..0856db87a 100644
--- a/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/AnnotateView.java
+++ b/bundles/org.eclipse.team.cvs.ui/src/org/eclipse/team/internal/ccvs/ui/AnnotateView.java
@@ -21,6 +21,7 @@ import org.eclipse.jface.text.BadLocationException;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.ITextSelection;
import org.eclipse.jface.viewers.ArrayContentProvider;
+import org.eclipse.jface.viewers.IPostSelectionProvider;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.jface.viewers.IStructuredSelection;
@@ -121,7 +122,7 @@ public class AnnotateView extends ViewPart implements ISelectionChangedListener
}
}
- viewer = new ListViewer(top, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER);
+ viewer = new ListViewer(top, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL);
viewer.setContentProvider(new ArrayContentProvider());
viewer.setLabelProvider(new LabelProvider());
viewer.addSelectionChangedListener(this);
@@ -141,6 +142,11 @@ public class AnnotateView extends ViewPart implements ISelectionChangedListener
document = provider.getDocument(editor.getEditorInput());
setTitle(Policy.bind("CVSAnnotateView.showFileAnnotation", new Object[] {cvsResource.getName()})); //$NON-NLS-1$
+ try {
+ setTitleToolTip(cvsResource.getIResource().getFullPath().toString());
+ } catch (CVSException e1) {
+ setTitleToolTip(cvsResource.getName());
+ }
if (!useHistoryView) {
return;
@@ -342,9 +348,12 @@ public class AnnotateView extends ViewPart implements ISelectionChangedListener
throw new InvocationTargetException(e);
}
// Hook Editor selection listener.
ITextEditor editor = (ITextEditor) part;
- editor.getSelectionProvider().addSelectionChangedListener(this);
+ if (editor.getSelectionProvider() instanceof IPostSelectionProvider) {
+ ((IPostSelectionProvider) editor.getSelectionProvider()).addPostSelectionChangedListener(this);
+ }
+
return part;
}
@@ -342,9 +348,12 @@ public class AnnotateView extends ViewPart implements ISelectionChangedListener
throw new InvocationTargetException(e);
}
- // Hook Editor selection listener.
+ // Hook Editor post selection listener.
ITextEditor editor = (ITextEditor) part;